"""CycloidalDisc"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_get_with_method,
    pythonnet_property_set,
    pythonnet_property_set_with_method,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.part_model import _2705

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_CYCLOIDAL_DISC = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.Cycloidal", "CycloidalDisc"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.cycloidal import _1667
    from mastapy._private.materials import _371
    from mastapy._private.system_model import _2452
    from mastapy._private.system_model.connections_and_sockets.cycloidal import _2599
    from mastapy._private.system_model.part_model import _2706, _2715, _2733, _2743

    Self = TypeVar("Self", bound="CycloidalDisc")
    CastSelf = TypeVar("CastSelf", bound="CycloidalDisc._Cast_CycloidalDisc")


__docformat__ = "restructuredtext en"
__all__ = ("CycloidalDisc",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CycloidalDisc:
    """Special nested class for casting CycloidalDisc to subclasses."""

    __parent__: "CycloidalDisc"

    @property
    def abstract_shaft(self: "CastSelf") -> "_2705.AbstractShaft":
        return self.__parent__._cast(_2705.AbstractShaft)

    @property
    def abstract_shaft_or_housing(self: "CastSelf") -> "_2706.AbstractShaftOrHousing":
        from mastapy._private.system_model.part_model import _2706

        return self.__parent__._cast(_2706.AbstractShaftOrHousing)

    @property
    def component(self: "CastSelf") -> "_2715.Component":
        from mastapy._private.system_model.part_model import _2715

        return self.__parent__._cast(_2715.Component)

    @property
    def part(self: "CastSelf") -> "_2743.Part":
        from mastapy._private.system_model.part_model import _2743

        return self.__parent__._cast(_2743.Part)

    @property
    def design_entity(self: "CastSelf") -> "_2452.DesignEntity":
        from mastapy._private.system_model import _2452

        return self.__parent__._cast(_2452.DesignEntity)

    @property
    def cycloidal_disc(self: "CastSelf") -> "CycloidalDisc":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CycloidalDisc(_2705.AbstractShaft):
    """CycloidalDisc

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYCLOIDAL_DISC

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def bore_diameter(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "BoreDiameter")

        if temp is None:
            return 0.0

        return temp

    @bore_diameter.setter
    @exception_bridge
    @enforce_parameter_types
    def bore_diameter(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "BoreDiameter", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def disc_material_database(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get_with_method(
            self.wrapped, "DiscMaterialDatabase", "SelectedItemName"
        )

        if temp is None:
            return ""

        return temp

    @disc_material_database.setter
    @exception_bridge
    @enforce_parameter_types
    def disc_material_database(self: "Self", value: "str") -> None:
        pythonnet_property_set_with_method(
            self.wrapped,
            "DiscMaterialDatabase",
            "SetSelectedItem",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def hole_diameter_for_eccentric_bearing(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "HoleDiameterForEccentricBearing")

        if temp is None:
            return 0.0

        return temp

    @hole_diameter_for_eccentric_bearing.setter
    @exception_bridge
    @enforce_parameter_types
    def hole_diameter_for_eccentric_bearing(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "HoleDiameterForEccentricBearing",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def length(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "Length")

        if temp is None:
            return 0.0

        return temp

    @length.setter
    @exception_bridge
    @enforce_parameter_types
    def length(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "Length", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def number_of_planetary_sockets(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfPlanetarySockets")

        if temp is None:
            return 0

        return temp

    @number_of_planetary_sockets.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_planetary_sockets(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfPlanetarySockets",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def cycloidal_disc_design(self: "Self") -> "_1667.CycloidalDiscDesign":
        """mastapy.cycloidal.CycloidalDiscDesign

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CycloidalDiscDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def disc_material(self: "Self") -> "_371.Material":
        """mastapy.materials.Material

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DiscMaterial")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def load_sharing_settings(self: "Self") -> "_2733.LoadSharingSettings":
        """mastapy.system_model.part_model.LoadSharingSettings

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LoadSharingSettings")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def planetary_bearing_sockets(
        self: "Self",
    ) -> "List[_2599.CycloidalDiscPlanetaryBearingSocket]":
        """List[mastapy.system_model.connections_and_sockets.cycloidal.CycloidalDiscPlanetaryBearingSocket]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "PlanetaryBearingSockets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CycloidalDisc":
        """Cast to another type.

        Returns:
            _Cast_CycloidalDisc
        """
        return _Cast_CycloidalDisc(self)



"""LoadedBearingResults"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.bearings import _2114

_LOADED_BEARING_RESULTS = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults", "LoadedBearingResults"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.bearings.bearing_designs import _2378
    from mastapy._private.bearings.bearing_results import (
        _2192,
        _2193,
        _2194,
        _2195,
        _2196,
        _2198,
        _2201,
    )
    from mastapy._private.bearings.bearing_results.fluid_film import (
        _2367,
        _2368,
        _2369,
        _2370,
        _2372,
        _2375,
        _2376,
    )
    from mastapy._private.bearings.bearing_results.rolling import (
        _2226,
        _2229,
        _2232,
        _2237,
        _2240,
        _2245,
        _2248,
        _2252,
        _2255,
        _2260,
        _2264,
        _2268,
        _2273,
        _2277,
        _2280,
        _2284,
        _2287,
        _2292,
        _2295,
        _2298,
        _2301,
        _2314,
    )
    from mastapy._private.math_utility.measured_vectors import _1781

    Self = TypeVar("Self", bound="LoadedBearingResults")
    CastSelf = TypeVar(
        "CastSelf", bound="LoadedBearingResults._Cast_LoadedBearingResults"
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedBearingResults",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LoadedBearingResults:
    """Special nested class for casting LoadedBearingResults to subclasses."""

    __parent__: "LoadedBearingResults"

    @property
    def bearing_load_case_results_lightweight(
        self: "CastSelf",
    ) -> "_2114.BearingLoadCaseResultsLightweight":
        return self.__parent__._cast(_2114.BearingLoadCaseResultsLightweight)

    @property
    def loaded_concept_axial_clearance_bearing_results(
        self: "CastSelf",
    ) -> "_2192.LoadedConceptAxialClearanceBearingResults":
        from mastapy._private.bearings.bearing_results import _2192

        return self.__parent__._cast(_2192.LoadedConceptAxialClearanceBearingResults)

    @property
    def loaded_concept_clearance_bearing_results(
        self: "CastSelf",
    ) -> "_2193.LoadedConceptClearanceBearingResults":
        from mastapy._private.bearings.bearing_results import _2193

        return self.__parent__._cast(_2193.LoadedConceptClearanceBearingResults)

    @property
    def loaded_concept_radial_clearance_bearing_results(
        self: "CastSelf",
    ) -> "_2194.LoadedConceptRadialClearanceBearingResults":
        from mastapy._private.bearings.bearing_results import _2194

        return self.__parent__._cast(_2194.LoadedConceptRadialClearanceBearingResults)

    @property
    def loaded_detailed_bearing_results(
        self: "CastSelf",
    ) -> "_2195.LoadedDetailedBearingResults":
        from mastapy._private.bearings.bearing_results import _2195

        return self.__parent__._cast(_2195.LoadedDetailedBearingResults)

    @property
    def loaded_linear_bearing_results(
        self: "CastSelf",
    ) -> "_2196.LoadedLinearBearingResults":
        from mastapy._private.bearings.bearing_results import _2196

        return self.__parent__._cast(_2196.LoadedLinearBearingResults)

    @property
    def loaded_non_linear_bearing_results(
        self: "CastSelf",
    ) -> "_2198.LoadedNonLinearBearingResults":
        from mastapy._private.bearings.bearing_results import _2198

        return self.__parent__._cast(_2198.LoadedNonLinearBearingResults)

    @property
    def loaded_angular_contact_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2226.LoadedAngularContactBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2226

        return self.__parent__._cast(_2226.LoadedAngularContactBallBearingResults)

    @property
    def loaded_angular_contact_thrust_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2229.LoadedAngularContactThrustBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2229

        return self.__parent__._cast(_2229.LoadedAngularContactThrustBallBearingResults)

    @property
    def loaded_asymmetric_spherical_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2232.LoadedAsymmetricSphericalRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2232

        return self.__parent__._cast(
            _2232.LoadedAsymmetricSphericalRollerBearingResults
        )

    @property
    def loaded_axial_thrust_cylindrical_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2237.LoadedAxialThrustCylindricalRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2237

        return self.__parent__._cast(
            _2237.LoadedAxialThrustCylindricalRollerBearingResults
        )

    @property
    def loaded_axial_thrust_needle_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2240.LoadedAxialThrustNeedleRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2240

        return self.__parent__._cast(_2240.LoadedAxialThrustNeedleRollerBearingResults)

    @property
    def loaded_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2245.LoadedBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2245

        return self.__parent__._cast(_2245.LoadedBallBearingResults)

    @property
    def loaded_crossed_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2248.LoadedCrossedRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2248

        return self.__parent__._cast(_2248.LoadedCrossedRollerBearingResults)

    @property
    def loaded_cylindrical_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2252.LoadedCylindricalRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2252

        return self.__parent__._cast(_2252.LoadedCylindricalRollerBearingResults)

    @property
    def loaded_deep_groove_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2255.LoadedDeepGrooveBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2255

        return self.__parent__._cast(_2255.LoadedDeepGrooveBallBearingResults)

    @property
    def loaded_four_point_contact_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2260.LoadedFourPointContactBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2260

        return self.__parent__._cast(_2260.LoadedFourPointContactBallBearingResults)

    @property
    def loaded_needle_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2264.LoadedNeedleRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2264

        return self.__parent__._cast(_2264.LoadedNeedleRollerBearingResults)

    @property
    def loaded_non_barrel_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2268.LoadedNonBarrelRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2268

        return self.__parent__._cast(_2268.LoadedNonBarrelRollerBearingResults)

    @property
    def loaded_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2273.LoadedRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2273

        return self.__parent__._cast(_2273.LoadedRollerBearingResults)

    @property
    def loaded_rolling_bearing_results(
        self: "CastSelf",
    ) -> "_2277.LoadedRollingBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2277

        return self.__parent__._cast(_2277.LoadedRollingBearingResults)

    @property
    def loaded_self_aligning_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2280.LoadedSelfAligningBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2280

        return self.__parent__._cast(_2280.LoadedSelfAligningBallBearingResults)

    @property
    def loaded_spherical_roller_radial_bearing_results(
        self: "CastSelf",
    ) -> "_2284.LoadedSphericalRollerRadialBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2284

        return self.__parent__._cast(_2284.LoadedSphericalRollerRadialBearingResults)

    @property
    def loaded_spherical_roller_thrust_bearing_results(
        self: "CastSelf",
    ) -> "_2287.LoadedSphericalRollerThrustBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2287

        return self.__parent__._cast(_2287.LoadedSphericalRollerThrustBearingResults)

    @property
    def loaded_taper_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2292.LoadedTaperRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2292

        return self.__parent__._cast(_2292.LoadedTaperRollerBearingResults)

    @property
    def loaded_three_point_contact_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2295.LoadedThreePointContactBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2295

        return self.__parent__._cast(_2295.LoadedThreePointContactBallBearingResults)

    @property
    def loaded_thrust_ball_bearing_results(
        self: "CastSelf",
    ) -> "_2298.LoadedThrustBallBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2298

        return self.__parent__._cast(_2298.LoadedThrustBallBearingResults)

    @property
    def loaded_toroidal_roller_bearing_results(
        self: "CastSelf",
    ) -> "_2301.LoadedToroidalRollerBearingResults":
        from mastapy._private.bearings.bearing_results.rolling import _2301

        return self.__parent__._cast(_2301.LoadedToroidalRollerBearingResults)

    @property
    def loaded_fluid_film_bearing_results(
        self: "CastSelf",
    ) -> "_2367.LoadedFluidFilmBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2367

        return self.__parent__._cast(_2367.LoadedFluidFilmBearingResults)

    @property
    def loaded_grease_filled_journal_bearing_results(
        self: "CastSelf",
    ) -> "_2368.LoadedGreaseFilledJournalBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2368

        return self.__parent__._cast(_2368.LoadedGreaseFilledJournalBearingResults)

    @property
    def loaded_pad_fluid_film_bearing_results(
        self: "CastSelf",
    ) -> "_2369.LoadedPadFluidFilmBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2369

        return self.__parent__._cast(_2369.LoadedPadFluidFilmBearingResults)

    @property
    def loaded_plain_journal_bearing_results(
        self: "CastSelf",
    ) -> "_2370.LoadedPlainJournalBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2370

        return self.__parent__._cast(_2370.LoadedPlainJournalBearingResults)

    @property
    def loaded_plain_oil_fed_journal_bearing(
        self: "CastSelf",
    ) -> "_2372.LoadedPlainOilFedJournalBearing":
        from mastapy._private.bearings.bearing_results.fluid_film import _2372

        return self.__parent__._cast(_2372.LoadedPlainOilFedJournalBearing)

    @property
    def loaded_tilting_pad_journal_bearing_results(
        self: "CastSelf",
    ) -> "_2375.LoadedTiltingPadJournalBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2375

        return self.__parent__._cast(_2375.LoadedTiltingPadJournalBearingResults)

    @property
    def loaded_tilting_pad_thrust_bearing_results(
        self: "CastSelf",
    ) -> "_2376.LoadedTiltingPadThrustBearingResults":
        from mastapy._private.bearings.bearing_results.fluid_film import _2376

        return self.__parent__._cast(_2376.LoadedTiltingPadThrustBearingResults)

    @property
    def loaded_bearing_results(self: "CastSelf") -> "LoadedBearingResults":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LoadedBearingResults(_2114.BearingLoadCaseResultsLightweight):
    """LoadedBearingResults

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOADED_BEARING_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def angle_of_gravity_from_z_axis(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AngleOfGravityFromZAxis")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def axial_displacement_preload(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "AxialDisplacementPreload")

        if temp is None:
            return 0.0

        return temp

    @axial_displacement_preload.setter
    @exception_bridge
    @enforce_parameter_types
    def axial_displacement_preload(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AxialDisplacementPreload",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def duration(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "Duration")

        if temp is None:
            return 0.0

        return temp

    @duration.setter
    @exception_bridge
    @enforce_parameter_types
    def duration(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "Duration", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def force_results_are_overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceResultsAreOverridden")

        if temp is None:
            return False

        return temp

    @property
    @exception_bridge
    def inner_ring_angular_rotation(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "InnerRingAngularRotation")

        if temp is None:
            return 0.0

        return temp

    @inner_ring_angular_rotation.setter
    @exception_bridge
    @enforce_parameter_types
    def inner_ring_angular_rotation(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "InnerRingAngularRotation",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def inner_ring_angular_velocity(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "InnerRingAngularVelocity")

        if temp is None:
            return 0.0

        return temp

    @inner_ring_angular_velocity.setter
    @exception_bridge
    @enforce_parameter_types
    def inner_ring_angular_velocity(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "InnerRingAngularVelocity",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def orientation(self: "Self") -> "_2201.Orientations":
        """mastapy.bearings.bearing_results.Orientations"""
        temp = pythonnet_property_get(self.wrapped, "Orientation")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Bearings.BearingResults.Orientations"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.bearings.bearing_results._2201", "Orientations"
        )(value)

    @orientation.setter
    @exception_bridge
    @enforce_parameter_types
    def orientation(self: "Self", value: "_2201.Orientations") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Bearings.BearingResults.Orientations"
        )
        pythonnet_property_set(self.wrapped, "Orientation", value)

    @property
    @exception_bridge
    def outer_ring_angular_rotation(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "OuterRingAngularRotation")

        if temp is None:
            return 0.0

        return temp

    @outer_ring_angular_rotation.setter
    @exception_bridge
    @enforce_parameter_types
    def outer_ring_angular_rotation(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "OuterRingAngularRotation",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def outer_ring_angular_velocity(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "OuterRingAngularVelocity")

        if temp is None:
            return 0.0

        return temp

    @outer_ring_angular_velocity.setter
    @exception_bridge
    @enforce_parameter_types
    def outer_ring_angular_velocity(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "OuterRingAngularVelocity",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def relative_angular_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RelativeAngularVelocity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def relative_axial_displacement(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RelativeAxialDisplacement")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def relative_radial_displacement(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RelativeRadialDisplacement")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def signed_relative_angular_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SignedRelativeAngularVelocity")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def specified_axial_internal_clearance(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "SpecifiedAxialInternalClearance")

        if temp is None:
            return 0.0

        return temp

    @specified_axial_internal_clearance.setter
    @exception_bridge
    @enforce_parameter_types
    def specified_axial_internal_clearance(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "SpecifiedAxialInternalClearance",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def specified_radial_internal_clearance(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "SpecifiedRadialInternalClearance")

        if temp is None:
            return 0.0

        return temp

    @specified_radial_internal_clearance.setter
    @exception_bridge
    @enforce_parameter_types
    def specified_radial_internal_clearance(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "SpecifiedRadialInternalClearance",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def bearing(self: "Self") -> "_2378.BearingDesign":
        """mastapy.bearings.bearing_designs.BearingDesign

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Bearing")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def force_on_inner_race(
        self: "Self",
    ) -> "_1781.VectorWithLinearAndAngularComponents":
        """mastapy.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ForceOnInnerRace")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def ring_results(self: "Self") -> "List[_2314.RingForceAndDisplacement]":
        """List[mastapy.bearings.bearing_results.rolling.RingForceAndDisplacement]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RingResults")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_LoadedBearingResults":
        """Cast to another type.

        Returns:
            _Cast_LoadedBearingResults
        """
        return _Cast_LoadedBearingResults(self)



"""GearMeshImplementationAnalysisDutyCycle"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.gears.analysis import _1368

_GEAR_MESH_IMPLEMENTATION_ANALYSIS_DUTY_CYCLE = python_net_import(
    "SMT.MastaAPI.Gears.Analysis", "GearMeshImplementationAnalysisDutyCycle"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.analysis import _1362
    from mastapy._private.gears.manufacturing.cylindrical import _744

    Self = TypeVar("Self", bound="GearMeshImplementationAnalysisDutyCycle")
    CastSelf = TypeVar(
        "CastSelf",
        bound="GearMeshImplementationAnalysisDutyCycle._Cast_GearMeshImplementationAnalysisDutyCycle",
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearMeshImplementationAnalysisDutyCycle",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearMeshImplementationAnalysisDutyCycle:
    """Special nested class for casting GearMeshImplementationAnalysisDutyCycle to subclasses."""

    __parent__: "GearMeshImplementationAnalysisDutyCycle"

    @property
    def gear_mesh_design_analysis(self: "CastSelf") -> "_1368.GearMeshDesignAnalysis":
        return self.__parent__._cast(_1368.GearMeshDesignAnalysis)

    @property
    def abstract_gear_mesh_analysis(
        self: "CastSelf",
    ) -> "_1362.AbstractGearMeshAnalysis":
        from mastapy._private.gears.analysis import _1362

        return self.__parent__._cast(_1362.AbstractGearMeshAnalysis)

    @property
    def cylindrical_manufactured_gear_mesh_duty_cycle(
        self: "CastSelf",
    ) -> "_744.CylindricalManufacturedGearMeshDutyCycle":
        from mastapy._private.gears.manufacturing.cylindrical import _744

        return self.__parent__._cast(_744.CylindricalManufacturedGearMeshDutyCycle)

    @property
    def gear_mesh_implementation_analysis_duty_cycle(
        self: "CastSelf",
    ) -> "GearMeshImplementationAnalysisDutyCycle":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearMeshImplementationAnalysisDutyCycle(_1368.GearMeshDesignAnalysis):
    """GearMeshImplementationAnalysisDutyCycle

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_MESH_IMPLEMENTATION_ANALYSIS_DUTY_CYCLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_GearMeshImplementationAnalysisDutyCycle":
        """Cast to another type.

        Returns:
            _Cast_GearMeshImplementationAnalysisDutyCycle
        """
        return _Cast_GearMeshImplementationAnalysisDutyCycle(self)



"""StraightBevelDiffGearSetDesign"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import conversion, utility
from mastapy._private.gears.gear_designs.bevel import _1328

_STRAIGHT_BEVEL_DIFF_GEAR_SET_DESIGN = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.StraightBevelDiff", "StraightBevelDiffGearSetDesign"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.gear_designs import _1074, _1076
    from mastapy._private.gears.gear_designs.agma_gleason_conical import _1341
    from mastapy._private.gears.gear_designs.conical import _1302
    from mastapy._private.gears.gear_designs.straight_bevel_diff import _1091, _1092

    Self = TypeVar("Self", bound="StraightBevelDiffGearSetDesign")
    CastSelf = TypeVar(
        "CastSelf",
        bound="StraightBevelDiffGearSetDesign._Cast_StraightBevelDiffGearSetDesign",
    )


__docformat__ = "restructuredtext en"
__all__ = ("StraightBevelDiffGearSetDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_StraightBevelDiffGearSetDesign:
    """Special nested class for casting StraightBevelDiffGearSetDesign to subclasses."""

    __parent__: "StraightBevelDiffGearSetDesign"

    @property
    def bevel_gear_set_design(self: "CastSelf") -> "_1328.BevelGearSetDesign":
        return self.__parent__._cast(_1328.BevelGearSetDesign)

    @property
    def agma_gleason_conical_gear_set_design(
        self: "CastSelf",
    ) -> "_1341.AGMAGleasonConicalGearSetDesign":
        from mastapy._private.gears.gear_designs.agma_gleason_conical import _1341

        return self.__parent__._cast(_1341.AGMAGleasonConicalGearSetDesign)

    @property
    def conical_gear_set_design(self: "CastSelf") -> "_1302.ConicalGearSetDesign":
        from mastapy._private.gears.gear_designs.conical import _1302

        return self.__parent__._cast(_1302.ConicalGearSetDesign)

    @property
    def gear_set_design(self: "CastSelf") -> "_1076.GearSetDesign":
        from mastapy._private.gears.gear_designs import _1076

        return self.__parent__._cast(_1076.GearSetDesign)

    @property
    def gear_design_component(self: "CastSelf") -> "_1074.GearDesignComponent":
        from mastapy._private.gears.gear_designs import _1074

        return self.__parent__._cast(_1074.GearDesignComponent)

    @property
    def straight_bevel_diff_gear_set_design(
        self: "CastSelf",
    ) -> "StraightBevelDiffGearSetDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class StraightBevelDiffGearSetDesign(_1328.BevelGearSetDesign):
    """StraightBevelDiffGearSetDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _STRAIGHT_BEVEL_DIFF_GEAR_SET_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def derating_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "DeratingFactor")

        if temp is None:
            return 0.0

        return temp

    @derating_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def derating_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "DeratingFactor", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def straight_bevel_diff_gears(
        self: "Self",
    ) -> "List[_1091.StraightBevelDiffGearDesign]":
        """List[mastapy.gears.gear_designs.straight_bevel_diff.StraightBevelDiffGearDesign]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StraightBevelDiffGears")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def straight_bevel_diff_meshes(
        self: "Self",
    ) -> "List[_1092.StraightBevelDiffGearMeshDesign]":
        """List[mastapy.gears.gear_designs.straight_bevel_diff.StraightBevelDiffGearMeshDesign]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StraightBevelDiffMeshes")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_StraightBevelDiffGearSetDesign":
        """Cast to another type.

        Returns:
            _Cast_StraightBevelDiffGearSetDesign
        """
        return _Cast_StraightBevelDiffGearSetDesign(self)



"""KlingelnbergCycloPalloidHypoidGearSingleFlankRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.gears.rating.klingelnberg_conical.kn3030 import _529

_KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.KlingelnbergConical.KN3030",
    "KlingelnbergCycloPalloidHypoidGearSingleFlankRating",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating import _477

    Self = TypeVar("Self", bound="KlingelnbergCycloPalloidHypoidGearSingleFlankRating")
    CastSelf = TypeVar(
        "CastSelf",
        bound="KlingelnbergCycloPalloidHypoidGearSingleFlankRating._Cast_KlingelnbergCycloPalloidHypoidGearSingleFlankRating",
    )


__docformat__ = "restructuredtext en"
__all__ = ("KlingelnbergCycloPalloidHypoidGearSingleFlankRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_KlingelnbergCycloPalloidHypoidGearSingleFlankRating:
    """Special nested class for casting KlingelnbergCycloPalloidHypoidGearSingleFlankRating to subclasses."""

    __parent__: "KlingelnbergCycloPalloidHypoidGearSingleFlankRating"

    @property
    def klingelnberg_cyclo_palloid_conical_gear_single_flank_rating(
        self: "CastSelf",
    ) -> "_529.KlingelnbergCycloPalloidConicalGearSingleFlankRating":
        return self.__parent__._cast(
            _529.KlingelnbergCycloPalloidConicalGearSingleFlankRating
        )

    @property
    def gear_single_flank_rating(self: "CastSelf") -> "_477.GearSingleFlankRating":
        from mastapy._private.gears.rating import _477

        return self.__parent__._cast(_477.GearSingleFlankRating)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_single_flank_rating(
        self: "CastSelf",
    ) -> "KlingelnbergCycloPalloidHypoidGearSingleFlankRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class KlingelnbergCycloPalloidHypoidGearSingleFlankRating(
    _529.KlingelnbergCycloPalloidConicalGearSingleFlankRating
):
    """KlingelnbergCycloPalloidHypoidGearSingleFlankRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_SINGLE_FLANK_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def tangential_speed(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TangentialSpeed")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_KlingelnbergCycloPalloidHypoidGearSingleFlankRating":
        """Cast to another type.

        Returns:
            _Cast_KlingelnbergCycloPalloidHypoidGearSingleFlankRating
        """
        return _Cast_KlingelnbergCycloPalloidHypoidGearSingleFlankRating(self)



"""MaterialDatabase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.utility.databases import _2062

_MATERIAL_DATABASE = python_net_import("SMT.MastaAPI.Materials", "MaterialDatabase")

if TYPE_CHECKING:
    from typing import Any, Type

    from mastapy._private.cycloidal import _1670, _1677
    from mastapy._private.electric_machines import _1432, _1446, _1466, _1481
    from mastapy._private.gears.materials import _698, _700, _704, _705, _707, _708
    from mastapy._private.materials import _371
    from mastapy._private.shafts import _25
    from mastapy._private.utility.databases import _2058, _2066

    Self = TypeVar("Self", bound="MaterialDatabase")
    CastSelf = TypeVar("CastSelf", bound="MaterialDatabase._Cast_MaterialDatabase")

T = TypeVar("T", bound="_371.Material")

__docformat__ = "restructuredtext en"
__all__ = ("MaterialDatabase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MaterialDatabase:
    """Special nested class for casting MaterialDatabase to subclasses."""

    __parent__: "MaterialDatabase"

    @property
    def named_database(self: "CastSelf") -> "_2062.NamedDatabase":
        return self.__parent__._cast(_2062.NamedDatabase)

    @property
    def sql_database(self: "CastSelf") -> "_2066.SQLDatabase":
        pass

        from mastapy._private.utility.databases import _2066

        return self.__parent__._cast(_2066.SQLDatabase)

    @property
    def database(self: "CastSelf") -> "_2058.Database":
        pass

        from mastapy._private.utility.databases import _2058

        return self.__parent__._cast(_2058.Database)

    @property
    def shaft_material_database(self: "CastSelf") -> "_25.ShaftMaterialDatabase":
        from mastapy._private.shafts import _25

        return self.__parent__._cast(_25.ShaftMaterialDatabase)

    @property
    def bevel_gear_abstract_material_database(
        self: "CastSelf",
    ) -> "_698.BevelGearAbstractMaterialDatabase":
        from mastapy._private.gears.materials import _698

        return self.__parent__._cast(_698.BevelGearAbstractMaterialDatabase)

    @property
    def bevel_gear_iso_material_database(
        self: "CastSelf",
    ) -> "_700.BevelGearISOMaterialDatabase":
        from mastapy._private.gears.materials import _700

        return self.__parent__._cast(_700.BevelGearISOMaterialDatabase)

    @property
    def cylindrical_gear_agma_material_database(
        self: "CastSelf",
    ) -> "_704.CylindricalGearAGMAMaterialDatabase":
        from mastapy._private.gears.materials import _704

        return self.__parent__._cast(_704.CylindricalGearAGMAMaterialDatabase)

    @property
    def cylindrical_gear_iso_material_database(
        self: "CastSelf",
    ) -> "_705.CylindricalGearISOMaterialDatabase":
        from mastapy._private.gears.materials import _705

        return self.__parent__._cast(_705.CylindricalGearISOMaterialDatabase)

    @property
    def cylindrical_gear_material_database(
        self: "CastSelf",
    ) -> "_707.CylindricalGearMaterialDatabase":
        from mastapy._private.gears.materials import _707

        return self.__parent__._cast(_707.CylindricalGearMaterialDatabase)

    @property
    def cylindrical_gear_plastic_material_database(
        self: "CastSelf",
    ) -> "_708.CylindricalGearPlasticMaterialDatabase":
        from mastapy._private.gears.materials import _708

        return self.__parent__._cast(_708.CylindricalGearPlasticMaterialDatabase)

    @property
    def general_electric_machine_material_database(
        self: "CastSelf",
    ) -> "_1432.GeneralElectricMachineMaterialDatabase":
        from mastapy._private.electric_machines import _1432

        return self.__parent__._cast(_1432.GeneralElectricMachineMaterialDatabase)

    @property
    def magnet_material_database(self: "CastSelf") -> "_1446.MagnetMaterialDatabase":
        from mastapy._private.electric_machines import _1446

        return self.__parent__._cast(_1446.MagnetMaterialDatabase)

    @property
    def stator_rotor_material_database(
        self: "CastSelf",
    ) -> "_1466.StatorRotorMaterialDatabase":
        from mastapy._private.electric_machines import _1466

        return self.__parent__._cast(_1466.StatorRotorMaterialDatabase)

    @property
    def winding_material_database(self: "CastSelf") -> "_1481.WindingMaterialDatabase":
        from mastapy._private.electric_machines import _1481

        return self.__parent__._cast(_1481.WindingMaterialDatabase)

    @property
    def cycloidal_disc_material_database(
        self: "CastSelf",
    ) -> "_1670.CycloidalDiscMaterialDatabase":
        from mastapy._private.cycloidal import _1670

        return self.__parent__._cast(_1670.CycloidalDiscMaterialDatabase)

    @property
    def ring_pins_material_database(
        self: "CastSelf",
    ) -> "_1677.RingPinsMaterialDatabase":
        from mastapy._private.cycloidal import _1677

        return self.__parent__._cast(_1677.RingPinsMaterialDatabase)

    @property
    def material_database(self: "CastSelf") -> "MaterialDatabase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class MaterialDatabase(_2062.NamedDatabase[T]):
    """MaterialDatabase

    This is a mastapy class.

    Generic Types:
        T
    """

    TYPE: ClassVar["Type"] = _MATERIAL_DATABASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_MaterialDatabase":
        """Cast to another type.

        Returns:
            _Cast_MaterialDatabase
        """
        return _Cast_MaterialDatabase(self)



"""TwoDimensionalFEModelForMechanicalAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.electric_machines import _1418, _1473

_TWO_DIMENSIONAL_FE_MODEL_FOR_MECHANICAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "TwoDimensionalFEModelForMechanicalAnalysis"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="TwoDimensionalFEModelForMechanicalAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="TwoDimensionalFEModelForMechanicalAnalysis._Cast_TwoDimensionalFEModelForMechanicalAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("TwoDimensionalFEModelForMechanicalAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TwoDimensionalFEModelForMechanicalAnalysis:
    """Special nested class for casting TwoDimensionalFEModelForMechanicalAnalysis to subclasses."""

    __parent__: "TwoDimensionalFEModelForMechanicalAnalysis"

    @property
    def two_dimensional_fe_model_for_analysis(
        self: "CastSelf",
    ) -> "_1473.TwoDimensionalFEModelForAnalysis":
        return self.__parent__._cast(_1473.TwoDimensionalFEModelForAnalysis)

    @property
    def two_dimensional_fe_model_for_mechanical_analysis(
        self: "CastSelf",
    ) -> "TwoDimensionalFEModelForMechanicalAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class TwoDimensionalFEModelForMechanicalAnalysis(
    _1473.TwoDimensionalFEModelForAnalysis[
        _1418.ElectricMachineMechanicalAnalysisMeshingOptions
    ]
):
    """TwoDimensionalFEModelForMechanicalAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TWO_DIMENSIONAL_FE_MODEL_FOR_MECHANICAL_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_TwoDimensionalFEModelForMechanicalAnalysis":
        """Cast to another type.

        Returns:
            _Cast_TwoDimensionalFEModelForMechanicalAnalysis
        """
        return _Cast_TwoDimensionalFEModelForMechanicalAnalysis(self)



"""CylindricalMeshManufacturingConfig"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.analysis import _1371

_CYLINDRICAL_MESH_MANUFACTURING_CONFIG = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical", "CylindricalMeshManufacturingConfig"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.analysis import _1362, _1368
    from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import (
        _857,
        _860,
        _861,
    )

    Self = TypeVar("Self", bound="CylindricalMeshManufacturingConfig")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalMeshManufacturingConfig._Cast_CylindricalMeshManufacturingConfig",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalMeshManufacturingConfig",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalMeshManufacturingConfig:
    """Special nested class for casting CylindricalMeshManufacturingConfig to subclasses."""

    __parent__: "CylindricalMeshManufacturingConfig"

    @property
    def gear_mesh_implementation_detail(
        self: "CastSelf",
    ) -> "_1371.GearMeshImplementationDetail":
        return self.__parent__._cast(_1371.GearMeshImplementationDetail)

    @property
    def gear_mesh_design_analysis(self: "CastSelf") -> "_1368.GearMeshDesignAnalysis":
        from mastapy._private.gears.analysis import _1368

        return self.__parent__._cast(_1368.GearMeshDesignAnalysis)

    @property
    def abstract_gear_mesh_analysis(
        self: "CastSelf",
    ) -> "_1362.AbstractGearMeshAnalysis":
        from mastapy._private.gears.analysis import _1362

        return self.__parent__._cast(_1362.AbstractGearMeshAnalysis)

    @property
    def cylindrical_mesh_manufacturing_config(
        self: "CastSelf",
    ) -> "CylindricalMeshManufacturingConfig":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalMeshManufacturingConfig(_1371.GearMeshImplementationDetail):
    """CylindricalMeshManufacturingConfig

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_MESH_MANUFACTURING_CONFIG

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def nominal_meshed_gear_a_as_manufactured_virtual(
        self: "Self",
    ) -> "_861.CylindricalManufacturedVirtualGearInMesh":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NominalMeshedGearAAsManufacturedVirtual"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def nominal_meshed_gear_b_as_manufactured_virtual(
        self: "Self",
    ) -> "_861.CylindricalManufacturedVirtualGearInMesh":
        """mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NominalMeshedGearBAsManufacturedVirtual"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_a_as_manufactured(self: "Self") -> "List[_857.CutterSimulationCalc]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearAAsManufactured")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def gear_b_as_manufactured(self: "Self") -> "List[_857.CutterSimulationCalc]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearBAsManufactured")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def meshed_gear_a_as_manufactured(
        self: "Self",
    ) -> "List[_860.CylindricalManufacturedRealGearInMesh]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedRealGearInMesh]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshedGearAAsManufactured")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def meshed_gear_a_as_manufactured_virtual(
        self: "Self",
    ) -> "List[_861.CylindricalManufacturedVirtualGearInMesh]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshedGearAAsManufacturedVirtual")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def meshed_gear_b_as_manufactured(
        self: "Self",
    ) -> "List[_860.CylindricalManufacturedRealGearInMesh]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedRealGearInMesh]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshedGearBAsManufactured")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def meshed_gear_b_as_manufactured_virtual(
        self: "Self",
    ) -> "List[_861.CylindricalManufacturedVirtualGearInMesh]":
        """List[mastapy.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MeshedGearBAsManufacturedVirtual")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalMeshManufacturingConfig":
        """Cast to another type.

        Returns:
            _Cast_CylindricalMeshManufacturingConfig
        """
        return _Cast_CylindricalMeshManufacturingConfig(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.detailed_rigid_connectors.splines._1602 import (
        CustomSplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1603 import (
        CustomSplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1604 import (
        DetailedSplineJointSettings,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1605 import (
        DIN5480SplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1606 import (
        DIN5480SplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1607 import (
        DudleyEffectiveLengthApproximationOption,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1608 import FitTypes
    from mastapy._private.detailed_rigid_connectors.splines._1609 import (
        GBT3478SplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1610 import (
        GBT3478SplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1611 import (
        HeatTreatmentTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1612 import (
        ISO4156SplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1613 import (
        ISO4156SplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1614 import (
        JISB1603SplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1615 import (
        ManufacturingTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1616 import Modules
    from mastapy._private.detailed_rigid_connectors.splines._1617 import (
        PressureAngleTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1618 import RootTypes
    from mastapy._private.detailed_rigid_connectors.splines._1619 import (
        SAEFatigueLifeFactorTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1620 import (
        SAESplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1621 import (
        SAESplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1622 import SAETorqueCycles
    from mastapy._private.detailed_rigid_connectors.splines._1623 import (
        SplineDesignTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1624 import (
        FinishingMethods,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1625 import (
        SplineFitClassType,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1626 import (
        SplineFixtureTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1627 import (
        SplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1628 import (
        SplineJointDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1629 import SplineMaterial
    from mastapy._private.detailed_rigid_connectors.splines._1630 import (
        SplineRatingTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1631 import (
        SplineToleranceClassTypes,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1632 import (
        StandardSplineHalfDesign,
    )
    from mastapy._private.detailed_rigid_connectors.splines._1633 import (
        StandardSplineJointDesign,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.detailed_rigid_connectors.splines._1602": ["CustomSplineHalfDesign"],
        "_private.detailed_rigid_connectors.splines._1603": ["CustomSplineJointDesign"],
        "_private.detailed_rigid_connectors.splines._1604": [
            "DetailedSplineJointSettings"
        ],
        "_private.detailed_rigid_connectors.splines._1605": ["DIN5480SplineHalfDesign"],
        "_private.detailed_rigid_connectors.splines._1606": [
            "DIN5480SplineJointDesign"
        ],
        "_private.detailed_rigid_connectors.splines._1607": [
            "DudleyEffectiveLengthApproximationOption"
        ],
        "_private.detailed_rigid_connectors.splines._1608": ["FitTypes"],
        "_private.detailed_rigid_connectors.splines._1609": ["GBT3478SplineHalfDesign"],
        "_private.detailed_rigid_connectors.splines._1610": [
            "GBT3478SplineJointDesign"
        ],
        "_private.detailed_rigid_connectors.splines._1611": ["HeatTreatmentTypes"],
        "_private.detailed_rigid_connectors.splines._1612": ["ISO4156SplineHalfDesign"],
        "_private.detailed_rigid_connectors.splines._1613": [
            "ISO4156SplineJointDesign"
        ],
        "_private.detailed_rigid_connectors.splines._1614": [
            "JISB1603SplineJointDesign"
        ],
        "_private.detailed_rigid_connectors.splines._1615": ["ManufacturingTypes"],
        "_private.detailed_rigid_connectors.splines._1616": ["Modules"],
        "_private.detailed_rigid_connectors.splines._1617": ["PressureAngleTypes"],
        "_private.detailed_rigid_connectors.splines._1618": ["RootTypes"],
        "_private.detailed_rigid_connectors.splines._1619": [
            "SAEFatigueLifeFactorTypes"
        ],
        "_private.detailed_rigid_connectors.splines._1620": ["SAESplineHalfDesign"],
        "_private.detailed_rigid_connectors.splines._1621": ["SAESplineJointDesign"],
        "_private.detailed_rigid_connectors.splines._1622": ["SAETorqueCycles"],
        "_private.detailed_rigid_connectors.splines._1623": ["SplineDesignTypes"],
        "_private.detailed_rigid_connectors.splines._1624": ["FinishingMethods"],
        "_private.detailed_rigid_connectors.splines._1625": ["SplineFitClassType"],
        "_private.detailed_rigid_connectors.splines._1626": ["SplineFixtureTypes"],
        "_private.detailed_rigid_connectors.splines._1627": ["SplineHalfDesign"],
        "_private.detailed_rigid_connectors.splines._1628": ["SplineJointDesign"],
        "_private.detailed_rigid_connectors.splines._1629": ["SplineMaterial"],
        "_private.detailed_rigid_connectors.splines._1630": ["SplineRatingTypes"],
        "_private.detailed_rigid_connectors.splines._1631": [
            "SplineToleranceClassTypes"
        ],
        "_private.detailed_rigid_connectors.splines._1632": [
            "StandardSplineHalfDesign"
        ],
        "_private.detailed_rigid_connectors.splines._1633": [
            "StandardSplineJointDesign"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "CustomSplineHalfDesign",
    "CustomSplineJointDesign",
    "DetailedSplineJointSettings",
    "DIN5480SplineHalfDesign",
    "DIN5480SplineJointDesign",
    "DudleyEffectiveLengthApproximationOption",
    "FitTypes",
    "GBT3478SplineHalfDesign",
    "GBT3478SplineJointDesign",
    "HeatTreatmentTypes",
    "ISO4156SplineHalfDesign",
    "ISO4156SplineJointDesign",
    "JISB1603SplineJointDesign",
    "ManufacturingTypes",
    "Modules",
    "PressureAngleTypes",
    "RootTypes",
    "SAEFatigueLifeFactorTypes",
    "SAESplineHalfDesign",
    "SAESplineJointDesign",
    "SAETorqueCycles",
    "SplineDesignTypes",
    "FinishingMethods",
    "SplineFitClassType",
    "SplineFixtureTypes",
    "SplineHalfDesign",
    "SplineJointDesign",
    "SplineMaterial",
    "SplineRatingTypes",
    "SplineToleranceClassTypes",
    "StandardSplineHalfDesign",
    "StandardSplineJointDesign",
)



"""SurfaceFinishes"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_SURFACE_FINISHES = python_net_import("SMT.MastaAPI.Shafts", "SurfaceFinishes")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="SurfaceFinishes")
    CastSelf = TypeVar("CastSelf", bound="SurfaceFinishes._Cast_SurfaceFinishes")


__docformat__ = "restructuredtext en"
__all__ = ("SurfaceFinishes",)


class SurfaceFinishes(Enum):
    """SurfaceFinishes

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _SURFACE_FINISHES

    HIGHLY_POLISHED_NOMINAL = 0
    POLISHED = 1
    GROUND = 2
    COLD_DRAWN_OR_MACHINED_63µIN_16µM = 3
    COLD_DRAWN_OR_MACHINED_125µIN_32µM = 4
    COLD_DRAWN_OR_MACHINED_250µIN_63µM = 5
    COLD_DRAWN_OR_MACHINED_500µIN_125µM = 6
    HOT_ROLLED = 7
    FORGED = 8
    USERSPECIFIED = 9


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


SurfaceFinishes.__setattr__ = __enum_setattr
SurfaceFinishes.__delattr__ = __enum_delattr



"""ISOScuffingResultsRow"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import utility
from mastapy._private.gears.rating.cylindrical import _597

_ISO_SCUFFING_RESULTS_ROW = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical", "ISOScuffingResultsRow"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ISOScuffingResultsRow")
    CastSelf = TypeVar(
        "CastSelf", bound="ISOScuffingResultsRow._Cast_ISOScuffingResultsRow"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ISOScuffingResultsRow",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ISOScuffingResultsRow:
    """Special nested class for casting ISOScuffingResultsRow to subclasses."""

    __parent__: "ISOScuffingResultsRow"

    @property
    def scuffing_results_row(self: "CastSelf") -> "_597.ScuffingResultsRow":
        return self.__parent__._cast(_597.ScuffingResultsRow)

    @property
    def iso_scuffing_results_row(self: "CastSelf") -> "ISOScuffingResultsRow":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ISOScuffingResultsRow(_597.ScuffingResultsRow):
    """ISOScuffingResultsRow

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ISO_SCUFFING_RESULTS_ROW

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def approach_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ApproachFactor")

        if temp is None:
            return 0.0

        return temp

    @approach_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def approach_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "ApproachFactor", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def contact_temperature(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ContactTemperature")

        if temp is None:
            return 0.0

        return temp

    @contact_temperature.setter
    @exception_bridge
    @enforce_parameter_types
    def contact_temperature(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ContactTemperature",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def flash_temperature(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "FlashTemperature")

        if temp is None:
            return 0.0

        return temp

    @flash_temperature.setter
    @exception_bridge
    @enforce_parameter_types
    def flash_temperature(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "FlashTemperature", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def geometry_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "GeometryFactor")

        if temp is None:
            return 0.0

        return temp

    @geometry_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def geometry_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "GeometryFactor", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def pinion_rolling_velocity(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PinionRollingVelocity")

        if temp is None:
            return 0.0

        return temp

    @pinion_rolling_velocity.setter
    @exception_bridge
    @enforce_parameter_types
    def pinion_rolling_velocity(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "PinionRollingVelocity",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def sliding_velocity(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "SlidingVelocity")

        if temp is None:
            return 0.0

        return temp

    @sliding_velocity.setter
    @exception_bridge
    @enforce_parameter_types
    def sliding_velocity(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "SlidingVelocity", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def thermo_elastic_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ThermoElasticFactor")

        if temp is None:
            return 0.0

        return temp

    @thermo_elastic_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def thermo_elastic_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ThermoElasticFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def wheel_rolling_velocity(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "WheelRollingVelocity")

        if temp is None:
            return 0.0

        return temp

    @wheel_rolling_velocity.setter
    @exception_bridge
    @enforce_parameter_types
    def wheel_rolling_velocity(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "WheelRollingVelocity",
            float(value) if value is not None else 0.0,
        )

    @property
    def cast_to(self: "Self") -> "_Cast_ISOScuffingResultsRow":
        """Cast to another type.

        Returns:
            _Cast_ISOScuffingResultsRow
        """
        return _Cast_ISOScuffingResultsRow(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.gear_designs.cylindrical._1124 import (
        AddendumModificationDistributionRule,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1125 import (
        BacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1126 import BasicRackProfiles
    from mastapy._private.gears.gear_designs.cylindrical._1127 import (
        CaseHardeningProperties,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1128 import (
        CreateNewSuitableCutterOption,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1129 import (
        CrossedAxisCylindricalGearPair,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1130 import (
        CrossedAxisCylindricalGearPairLineContact,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1131 import (
        CrossedAxisCylindricalGearPairPointContact,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1132 import (
        Customer102DataSheetChangeLog,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1133 import (
        Customer102DataSheetChangeLogItem,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1134 import (
        Customer102DataSheetNote,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1135 import (
        Customer102DataSheetNotes,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1136 import (
        Customer102DataSheetTolerances,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1137 import (
        Customer102ToleranceDefinition,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1138 import (
        CylindricalGearAbstractRack,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1139 import (
        CylindricalGearAbstractRackFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1140 import (
        CylindricalGearBasicRack,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1141 import (
        CylindricalGearBasicRackFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1142 import (
        CylindricalGearCuttingOptions,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1143 import (
        CylindricalGearDefaults,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1144 import (
        CylindricalGearDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1145 import (
        CylindricalGearDesignConstraint,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1146 import (
        CylindricalGearDesignConstraints,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1147 import (
        CylindricalGearDesignConstraintsDatabase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1148 import (
        CylindricalGearDesignConstraintSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1149 import (
        CylindricalGearFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1150 import (
        CylindricalGearMeshDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1151 import (
        CylindricalGearMeshFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1152 import (
        CylindricalGearMicroGeometrySettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1153 import (
        CylindricalGearMicroGeometrySettingsDatabase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1154 import (
        CylindricalGearMicroGeometrySettingsItem,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1155 import (
        CylindricalGearPinionTypeCutter,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1156 import (
        CylindricalGearPinionTypeCutterFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1157 import (
        CylindricalGearProfileMeasurement,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1158 import (
        CylindricalGearProfileMeasurementType,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1159 import (
        CylindricalGearProfileModifications,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1160 import (
        CylindricalGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1161 import (
        CylindricalGearSetFlankDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1162 import (
        CylindricalGearSetMacroGeometryOptimiser,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1163 import (
        CylindricalGearSetManufacturingConfigurationSelection,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1164 import (
        CylindricalGearSetMicroGeometrySettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1165 import (
        CylindricalGearSetOptimisationWrapper,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1166 import (
        CylindricalGearTableMGItemDetail,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1167 import (
        CylindricalGearTableWithMGCharts,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1168 import (
        CylindricalGearToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1169 import (
        CylindricalMeshAngularBacklash,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1170 import (
        CylindricalMeshedGear,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1171 import (
        CylindricalMeshedGearFlank,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1172 import (
        CylindricalMeshLinearBacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1173 import (
        CylindricalPlanetaryGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1174 import (
        CylindricalPlanetGearDesign,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1175 import (
        DIN3967AllowanceSeries,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1176 import (
        DIN3967ToleranceSeries,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1177 import (
        DoubleAxisScaleAndRange,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1178 import (
        FinishToothThicknessDesignSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1179 import GearFitSystems
    from mastapy._private.gears.gear_designs.cylindrical._1180 import (
        GearManufacturingConfigSetupViewModel,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1181 import (
        GearSetManufacturingConfigurationSetup,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1182 import (
        GeometrySpecificationType,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1183 import (
        HardenedMaterialProperties,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1184 import (
        HardnessProfileCalculationMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1185 import HeatTreatmentType
    from mastapy._private.gears.gear_designs.cylindrical._1186 import ISO6336Geometry
    from mastapy._private.gears.gear_designs.cylindrical._1187 import (
        ISO6336GeometryBase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1188 import (
        ISO6336GeometryForShapedGears,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1189 import (
        ISO6336GeometryManufactured,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1190 import (
        LinearBacklashSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1191 import (
        LTCALoadCaseModifiableSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1192 import LTCASettings
    from mastapy._private.gears.gear_designs.cylindrical._1193 import (
        MicroGeometryConvention,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1194 import (
        MicroGeometryProfileConvention,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1195 import Micropitting
    from mastapy._private.gears.gear_designs.cylindrical._1196 import (
        MullerResidualStressDefinition,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1197 import (
        NamedPlanetAssemblyIndex,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1198 import (
        NamedPlanetSideBandAmplitudeFactor,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1199 import (
        PlanetGearSetPhaseRequirement,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1200 import (
        ReadonlyToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1201 import (
        RelativeMeasurementViewModel,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1202 import (
        RelativeValuesSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1203 import (
        ResidualStressCalculationMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1204 import (
        RootStressSurfaceChartOption,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1205 import Scuffing
    from mastapy._private.gears.gear_designs.cylindrical._1206 import (
        ScuffingCoefficientOfFrictionMethods,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1207 import (
        ScuffingTemperatureMethodsAGMA,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1208 import (
        ScuffingTemperatureMethodsISO,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1209 import ShaperEdgeTypes
    from mastapy._private.gears.gear_designs.cylindrical._1210 import (
        SpurGearLoadSharingCodes,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1211 import StandardRack
    from mastapy._private.gears.gear_designs.cylindrical._1212 import StandardRackFlank
    from mastapy._private.gears.gear_designs.cylindrical._1213 import SurfaceRoughness
    from mastapy._private.gears.gear_designs.cylindrical._1214 import ThicknessType
    from mastapy._private.gears.gear_designs.cylindrical._1215 import (
        TiffAnalysisSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1216 import (
        TipAlterationCoefficientMethod,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1217 import (
        TolerancedMetalMeasurements,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1218 import (
        TolerancedValueSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1219 import (
        ToothFlankFractureAnalysisSettings,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1220 import (
        ToothThicknessSpecification,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1221 import (
        ToothThicknessSpecificationBase,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1222 import (
        TypeOfMechanismHousing,
    )
    from mastapy._private.gears.gear_designs.cylindrical._1223 import Usage
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_designs.cylindrical._1124": [
            "AddendumModificationDistributionRule"
        ],
        "_private.gears.gear_designs.cylindrical._1125": ["BacklashSpecification"],
        "_private.gears.gear_designs.cylindrical._1126": ["BasicRackProfiles"],
        "_private.gears.gear_designs.cylindrical._1127": ["CaseHardeningProperties"],
        "_private.gears.gear_designs.cylindrical._1128": [
            "CreateNewSuitableCutterOption"
        ],
        "_private.gears.gear_designs.cylindrical._1129": [
            "CrossedAxisCylindricalGearPair"
        ],
        "_private.gears.gear_designs.cylindrical._1130": [
            "CrossedAxisCylindricalGearPairLineContact"
        ],
        "_private.gears.gear_designs.cylindrical._1131": [
            "CrossedAxisCylindricalGearPairPointContact"
        ],
        "_private.gears.gear_designs.cylindrical._1132": [
            "Customer102DataSheetChangeLog"
        ],
        "_private.gears.gear_designs.cylindrical._1133": [
            "Customer102DataSheetChangeLogItem"
        ],
        "_private.gears.gear_designs.cylindrical._1134": ["Customer102DataSheetNote"],
        "_private.gears.gear_designs.cylindrical._1135": ["Customer102DataSheetNotes"],
        "_private.gears.gear_designs.cylindrical._1136": [
            "Customer102DataSheetTolerances"
        ],
        "_private.gears.gear_designs.cylindrical._1137": [
            "Customer102ToleranceDefinition"
        ],
        "_private.gears.gear_designs.cylindrical._1138": [
            "CylindricalGearAbstractRack"
        ],
        "_private.gears.gear_designs.cylindrical._1139": [
            "CylindricalGearAbstractRackFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1140": ["CylindricalGearBasicRack"],
        "_private.gears.gear_designs.cylindrical._1141": [
            "CylindricalGearBasicRackFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1142": [
            "CylindricalGearCuttingOptions"
        ],
        "_private.gears.gear_designs.cylindrical._1143": ["CylindricalGearDefaults"],
        "_private.gears.gear_designs.cylindrical._1144": ["CylindricalGearDesign"],
        "_private.gears.gear_designs.cylindrical._1145": [
            "CylindricalGearDesignConstraint"
        ],
        "_private.gears.gear_designs.cylindrical._1146": [
            "CylindricalGearDesignConstraints"
        ],
        "_private.gears.gear_designs.cylindrical._1147": [
            "CylindricalGearDesignConstraintsDatabase"
        ],
        "_private.gears.gear_designs.cylindrical._1148": [
            "CylindricalGearDesignConstraintSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1149": ["CylindricalGearFlankDesign"],
        "_private.gears.gear_designs.cylindrical._1150": ["CylindricalGearMeshDesign"],
        "_private.gears.gear_designs.cylindrical._1151": [
            "CylindricalGearMeshFlankDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1152": [
            "CylindricalGearMicroGeometrySettings"
        ],
        "_private.gears.gear_designs.cylindrical._1153": [
            "CylindricalGearMicroGeometrySettingsDatabase"
        ],
        "_private.gears.gear_designs.cylindrical._1154": [
            "CylindricalGearMicroGeometrySettingsItem"
        ],
        "_private.gears.gear_designs.cylindrical._1155": [
            "CylindricalGearPinionTypeCutter"
        ],
        "_private.gears.gear_designs.cylindrical._1156": [
            "CylindricalGearPinionTypeCutterFlank"
        ],
        "_private.gears.gear_designs.cylindrical._1157": [
            "CylindricalGearProfileMeasurement"
        ],
        "_private.gears.gear_designs.cylindrical._1158": [
            "CylindricalGearProfileMeasurementType"
        ],
        "_private.gears.gear_designs.cylindrical._1159": [
            "CylindricalGearProfileModifications"
        ],
        "_private.gears.gear_designs.cylindrical._1160": ["CylindricalGearSetDesign"],
        "_private.gears.gear_designs.cylindrical._1161": [
            "CylindricalGearSetFlankDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1162": [
            "CylindricalGearSetMacroGeometryOptimiser"
        ],
        "_private.gears.gear_designs.cylindrical._1163": [
            "CylindricalGearSetManufacturingConfigurationSelection"
        ],
        "_private.gears.gear_designs.cylindrical._1164": [
            "CylindricalGearSetMicroGeometrySettings"
        ],
        "_private.gears.gear_designs.cylindrical._1165": [
            "CylindricalGearSetOptimisationWrapper"
        ],
        "_private.gears.gear_designs.cylindrical._1166": [
            "CylindricalGearTableMGItemDetail"
        ],
        "_private.gears.gear_designs.cylindrical._1167": [
            "CylindricalGearTableWithMGCharts"
        ],
        "_private.gears.gear_designs.cylindrical._1168": [
            "CylindricalGearToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1169": [
            "CylindricalMeshAngularBacklash"
        ],
        "_private.gears.gear_designs.cylindrical._1170": ["CylindricalMeshedGear"],
        "_private.gears.gear_designs.cylindrical._1171": ["CylindricalMeshedGearFlank"],
        "_private.gears.gear_designs.cylindrical._1172": [
            "CylindricalMeshLinearBacklashSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1173": [
            "CylindricalPlanetaryGearSetDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1174": [
            "CylindricalPlanetGearDesign"
        ],
        "_private.gears.gear_designs.cylindrical._1175": ["DIN3967AllowanceSeries"],
        "_private.gears.gear_designs.cylindrical._1176": ["DIN3967ToleranceSeries"],
        "_private.gears.gear_designs.cylindrical._1177": ["DoubleAxisScaleAndRange"],
        "_private.gears.gear_designs.cylindrical._1178": [
            "FinishToothThicknessDesignSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1179": ["GearFitSystems"],
        "_private.gears.gear_designs.cylindrical._1180": [
            "GearManufacturingConfigSetupViewModel"
        ],
        "_private.gears.gear_designs.cylindrical._1181": [
            "GearSetManufacturingConfigurationSetup"
        ],
        "_private.gears.gear_designs.cylindrical._1182": ["GeometrySpecificationType"],
        "_private.gears.gear_designs.cylindrical._1183": ["HardenedMaterialProperties"],
        "_private.gears.gear_designs.cylindrical._1184": [
            "HardnessProfileCalculationMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1185": ["HeatTreatmentType"],
        "_private.gears.gear_designs.cylindrical._1186": ["ISO6336Geometry"],
        "_private.gears.gear_designs.cylindrical._1187": ["ISO6336GeometryBase"],
        "_private.gears.gear_designs.cylindrical._1188": [
            "ISO6336GeometryForShapedGears"
        ],
        "_private.gears.gear_designs.cylindrical._1189": [
            "ISO6336GeometryManufactured"
        ],
        "_private.gears.gear_designs.cylindrical._1190": [
            "LinearBacklashSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1191": [
            "LTCALoadCaseModifiableSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1192": ["LTCASettings"],
        "_private.gears.gear_designs.cylindrical._1193": ["MicroGeometryConvention"],
        "_private.gears.gear_designs.cylindrical._1194": [
            "MicroGeometryProfileConvention"
        ],
        "_private.gears.gear_designs.cylindrical._1195": ["Micropitting"],
        "_private.gears.gear_designs.cylindrical._1196": [
            "MullerResidualStressDefinition"
        ],
        "_private.gears.gear_designs.cylindrical._1197": ["NamedPlanetAssemblyIndex"],
        "_private.gears.gear_designs.cylindrical._1198": [
            "NamedPlanetSideBandAmplitudeFactor"
        ],
        "_private.gears.gear_designs.cylindrical._1199": [
            "PlanetGearSetPhaseRequirement"
        ],
        "_private.gears.gear_designs.cylindrical._1200": [
            "ReadonlyToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1201": [
            "RelativeMeasurementViewModel"
        ],
        "_private.gears.gear_designs.cylindrical._1202": [
            "RelativeValuesSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1203": [
            "ResidualStressCalculationMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1204": [
            "RootStressSurfaceChartOption"
        ],
        "_private.gears.gear_designs.cylindrical._1205": ["Scuffing"],
        "_private.gears.gear_designs.cylindrical._1206": [
            "ScuffingCoefficientOfFrictionMethods"
        ],
        "_private.gears.gear_designs.cylindrical._1207": [
            "ScuffingTemperatureMethodsAGMA"
        ],
        "_private.gears.gear_designs.cylindrical._1208": [
            "ScuffingTemperatureMethodsISO"
        ],
        "_private.gears.gear_designs.cylindrical._1209": ["ShaperEdgeTypes"],
        "_private.gears.gear_designs.cylindrical._1210": ["SpurGearLoadSharingCodes"],
        "_private.gears.gear_designs.cylindrical._1211": ["StandardRack"],
        "_private.gears.gear_designs.cylindrical._1212": ["StandardRackFlank"],
        "_private.gears.gear_designs.cylindrical._1213": ["SurfaceRoughness"],
        "_private.gears.gear_designs.cylindrical._1214": ["ThicknessType"],
        "_private.gears.gear_designs.cylindrical._1215": ["TiffAnalysisSettings"],
        "_private.gears.gear_designs.cylindrical._1216": [
            "TipAlterationCoefficientMethod"
        ],
        "_private.gears.gear_designs.cylindrical._1217": [
            "TolerancedMetalMeasurements"
        ],
        "_private.gears.gear_designs.cylindrical._1218": [
            "TolerancedValueSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1219": [
            "ToothFlankFractureAnalysisSettings"
        ],
        "_private.gears.gear_designs.cylindrical._1220": [
            "ToothThicknessSpecification"
        ],
        "_private.gears.gear_designs.cylindrical._1221": [
            "ToothThicknessSpecificationBase"
        ],
        "_private.gears.gear_designs.cylindrical._1222": ["TypeOfMechanismHousing"],
        "_private.gears.gear_designs.cylindrical._1223": ["Usage"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AddendumModificationDistributionRule",
    "BacklashSpecification",
    "BasicRackProfiles",
    "CaseHardeningProperties",
    "CreateNewSuitableCutterOption",
    "CrossedAxisCylindricalGearPair",
    "CrossedAxisCylindricalGearPairLineContact",
    "CrossedAxisCylindricalGearPairPointContact",
    "Customer102DataSheetChangeLog",
    "Customer102DataSheetChangeLogItem",
    "Customer102DataSheetNote",
    "Customer102DataSheetNotes",
    "Customer102DataSheetTolerances",
    "Customer102ToleranceDefinition",
    "CylindricalGearAbstractRack",
    "CylindricalGearAbstractRackFlank",
    "CylindricalGearBasicRack",
    "CylindricalGearBasicRackFlank",
    "CylindricalGearCuttingOptions",
    "CylindricalGearDefaults",
    "CylindricalGearDesign",
    "CylindricalGearDesignConstraint",
    "CylindricalGearDesignConstraints",
    "CylindricalGearDesignConstraintsDatabase",
    "CylindricalGearDesignConstraintSettings",
    "CylindricalGearFlankDesign",
    "CylindricalGearMeshDesign",
    "CylindricalGearMeshFlankDesign",
    "CylindricalGearMicroGeometrySettings",
    "CylindricalGearMicroGeometrySettingsDatabase",
    "CylindricalGearMicroGeometrySettingsItem",
    "CylindricalGearPinionTypeCutter",
    "CylindricalGearPinionTypeCutterFlank",
    "CylindricalGearProfileMeasurement",
    "CylindricalGearProfileMeasurementType",
    "CylindricalGearProfileModifications",
    "CylindricalGearSetDesign",
    "CylindricalGearSetFlankDesign",
    "CylindricalGearSetMacroGeometryOptimiser",
    "CylindricalGearSetManufacturingConfigurationSelection",
    "CylindricalGearSetMicroGeometrySettings",
    "CylindricalGearSetOptimisationWrapper",
    "CylindricalGearTableMGItemDetail",
    "CylindricalGearTableWithMGCharts",
    "CylindricalGearToothThicknessSpecification",
    "CylindricalMeshAngularBacklash",
    "CylindricalMeshedGear",
    "CylindricalMeshedGearFlank",
    "CylindricalMeshLinearBacklashSpecification",
    "CylindricalPlanetaryGearSetDesign",
    "CylindricalPlanetGearDesign",
    "DIN3967AllowanceSeries",
    "DIN3967ToleranceSeries",
    "DoubleAxisScaleAndRange",
    "FinishToothThicknessDesignSpecification",
    "GearFitSystems",
    "GearManufacturingConfigSetupViewModel",
    "GearSetManufacturingConfigurationSetup",
    "GeometrySpecificationType",
    "HardenedMaterialProperties",
    "HardnessProfileCalculationMethod",
    "HeatTreatmentType",
    "ISO6336Geometry",
    "ISO6336GeometryBase",
    "ISO6336GeometryForShapedGears",
    "ISO6336GeometryManufactured",
    "LinearBacklashSpecification",
    "LTCALoadCaseModifiableSettings",
    "LTCASettings",
    "MicroGeometryConvention",
    "MicroGeometryProfileConvention",
    "Micropitting",
    "MullerResidualStressDefinition",
    "NamedPlanetAssemblyIndex",
    "NamedPlanetSideBandAmplitudeFactor",
    "PlanetGearSetPhaseRequirement",
    "ReadonlyToothThicknessSpecification",
    "RelativeMeasurementViewModel",
    "RelativeValuesSpecification",
    "ResidualStressCalculationMethod",
    "RootStressSurfaceChartOption",
    "Scuffing",
    "ScuffingCoefficientOfFrictionMethods",
    "ScuffingTemperatureMethodsAGMA",
    "ScuffingTemperatureMethodsISO",
    "ShaperEdgeTypes",
    "SpurGearLoadSharingCodes",
    "StandardRack",
    "StandardRackFlank",
    "SurfaceRoughness",
    "ThicknessType",
    "TiffAnalysisSettings",
    "TipAlterationCoefficientMethod",
    "TolerancedMetalMeasurements",
    "TolerancedValueSpecification",
    "ToothFlankFractureAnalysisSettings",
    "ToothThicknessSpecification",
    "ToothThicknessSpecificationBase",
    "TypeOfMechanismHousing",
    "Usage",
)



"""LubricantViscosityClassISO"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_LUBRICANT_VISCOSITY_CLASS_ISO = python_net_import(
    "SMT.MastaAPI.Materials", "LubricantViscosityClassISO"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="LubricantViscosityClassISO")
    CastSelf = TypeVar(
        "CastSelf", bound="LubricantViscosityClassISO._Cast_LubricantViscosityClassISO"
    )


__docformat__ = "restructuredtext en"
__all__ = ("LubricantViscosityClassISO",)


class LubricantViscosityClassISO(Enum):
    """LubricantViscosityClassISO

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _LUBRICANT_VISCOSITY_CLASS_ISO

    ISO_VG_12 = 12
    ISO_VG_17 = 17
    ISO_VG_22 = 22
    ISO_VG_23 = 23
    ISO_VG_32 = 32
    ISO_VG_46 = 46
    ISO_VG_68 = 68
    ISO_VG_100 = 100
    ISO_VG_150 = 150
    ISO_VG_220 = 220
    ISO_VG_320 = 320
    ISO_VG_460 = 460
    ISO_VG_680 = 680
    ISO_VG_1000 = 1000
    ISO_VG_1500 = 1500
    ISO_VG_2200 = 2200
    ISO_VG_3200 = 3200
    ISO_VG_6800 = 6800


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


LubricantViscosityClassISO.__setattr__ = __enum_setattr
LubricantViscosityClassISO.__delattr__ = __enum_delattr



"""ConicalGearSetSteadyStateSynchronousResponseOnAShaft"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
    _3606,
)

_CONICAL_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft",
    "ConicalGearSetSteadyStateSynchronousResponseOnAShaft",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
        _3547,
        _3552,
        _3559,
        _3564,
        _3579,
        _3581,
        _3610,
        _3614,
        _3617,
        _3620,
        _3628,
        _3647,
        _3649,
        _3656,
        _3659,
        _3677,
    )
    from mastapy._private.system_model.part_model.gears import _2806

    Self = TypeVar("Self", bound="ConicalGearSetSteadyStateSynchronousResponseOnAShaft")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalGearSetSteadyStateSynchronousResponseOnAShaft._Cast_ConicalGearSetSteadyStateSynchronousResponseOnAShaft",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearSetSteadyStateSynchronousResponseOnAShaft",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalGearSetSteadyStateSynchronousResponseOnAShaft:
    """Special nested class for casting ConicalGearSetSteadyStateSynchronousResponseOnAShaft to subclasses."""

    __parent__: "ConicalGearSetSteadyStateSynchronousResponseOnAShaft"

    @property
    def gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3606.GearSetSteadyStateSynchronousResponseOnAShaft":
        return self.__parent__._cast(
            _3606.GearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def specialised_assembly_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3647.SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3647,
        )

        return self.__parent__._cast(
            _3647.SpecialisedAssemblySteadyStateSynchronousResponseOnAShaft
        )

    @property
    def abstract_assembly_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3547.AbstractAssemblySteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3547,
        )

        return self.__parent__._cast(
            _3547.AbstractAssemblySteadyStateSynchronousResponseOnAShaft
        )

    @property
    def part_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3628.PartSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3628,
        )

        return self.__parent__._cast(_3628.PartSteadyStateSynchronousResponseOnAShaft)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3552.AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3552,
        )

        return self.__parent__._cast(
            _3552.AGMAGleasonConicalGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_differential_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3559.BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3559,
        )

        return self.__parent__._cast(
            _3559.BevelDifferentialGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3564.BevelGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3564,
        )

        return self.__parent__._cast(
            _3564.BevelGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def hypoid_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3610.HypoidGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3610,
        )

        return self.__parent__._cast(
            _3610.HypoidGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3614.KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3614,
        )

        return self.__parent__._cast(
            _3614.KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3617.KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3617,
        )

        return self.__parent__._cast(
            _3617.KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3620.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3620,
        )

        return self.__parent__._cast(
            _3620.KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def spiral_bevel_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3649.SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3649,
        )

        return self.__parent__._cast(
            _3649.SpiralBevelGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_diff_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3656.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3656,
        )

        return self.__parent__._cast(
            _3656.StraightBevelDiffGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3659.StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3659,
        )

        return self.__parent__._cast(
            _3659.StraightBevelGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def zerol_bevel_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3677.ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3677,
        )

        return self.__parent__._cast(
            _3677.ZerolBevelGearSetSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def conical_gear_set_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "ConicalGearSetSteadyStateSynchronousResponseOnAShaft":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConicalGearSetSteadyStateSynchronousResponseOnAShaft(
    _3606.GearSetSteadyStateSynchronousResponseOnAShaft
):
    """ConicalGearSetSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _CONICAL_GEAR_SET_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2806.ConicalGearSet":
        """mastapy.system_model.part_model.gears.ConicalGearSet

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gears_steady_state_synchronous_response_on_a_shaft(
        self: "Self",
    ) -> "List[_3581.ConicalGearSteadyStateSynchronousResponseOnAShaft]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.ConicalGearSteadyStateSynchronousResponseOnAShaft]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GearsSteadyStateSynchronousResponseOnAShaft"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def conical_gears_steady_state_synchronous_response_on_a_shaft(
        self: "Self",
    ) -> "List[_3581.ConicalGearSteadyStateSynchronousResponseOnAShaft]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.ConicalGearSteadyStateSynchronousResponseOnAShaft]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ConicalGearsSteadyStateSynchronousResponseOnAShaft"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def meshes_steady_state_synchronous_response_on_a_shaft(
        self: "Self",
    ) -> "List[_3579.ConicalGearMeshSteadyStateSynchronousResponseOnAShaft]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.ConicalGearMeshSteadyStateSynchronousResponseOnAShaft]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MeshesSteadyStateSynchronousResponseOnAShaft"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def conical_meshes_steady_state_synchronous_response_on_a_shaft(
        self: "Self",
    ) -> "List[_3579.ConicalGearMeshSteadyStateSynchronousResponseOnAShaft]":
        """List[mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.ConicalGearMeshSteadyStateSynchronousResponseOnAShaft]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ConicalMeshesSteadyStateSynchronousResponseOnAShaft"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_ConicalGearSetSteadyStateSynchronousResponseOnAShaft":
        """Cast to another type.

        Returns:
            _Cast_ConicalGearSetSteadyStateSynchronousResponseOnAShaft
        """
        return _Cast_ConicalGearSetSteadyStateSynchronousResponseOnAShaft(self)



"""TransientSolver"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.nodal_analysis.system_solvers import _115

_TRANSIENT_SOLVER = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.SystemSolvers", "TransientSolver"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.nodal_analysis import _96
    from mastapy._private.nodal_analysis.system_solvers import (
        _112,
        _114,
        _116,
        _117,
        _118,
        _121,
        _125,
        _126,
        _127,
        _130,
    )

    Self = TypeVar("Self", bound="TransientSolver")
    CastSelf = TypeVar("CastSelf", bound="TransientSolver._Cast_TransientSolver")


__docformat__ = "restructuredtext en"
__all__ = ("TransientSolver",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TransientSolver:
    """Special nested class for casting TransientSolver to subclasses."""

    __parent__: "TransientSolver"

    @property
    def dynamic_solver(self: "CastSelf") -> "_115.DynamicSolver":
        return self.__parent__._cast(_115.DynamicSolver)

    @property
    def stiffness_solver(self: "CastSelf") -> "_127.StiffnessSolver":
        from mastapy._private.nodal_analysis.system_solvers import _127

        return self.__parent__._cast(_127.StiffnessSolver)

    @property
    def solver(self: "CastSelf") -> "_125.Solver":
        from mastapy._private.nodal_analysis.system_solvers import _125

        return self.__parent__._cast(_125.Solver)

    @property
    def backward_euler_transient_solver(
        self: "CastSelf",
    ) -> "_112.BackwardEulerTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _112

        return self.__parent__._cast(_112.BackwardEulerTransientSolver)

    @property
    def dirk_transient_solver(self: "CastSelf") -> "_114.DirkTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _114

        return self.__parent__._cast(_114.DirkTransientSolver)

    @property
    def internal_transient_solver(self: "CastSelf") -> "_116.InternalTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _116

        return self.__parent__._cast(_116.InternalTransientSolver)

    @property
    def lobatto_iiic_transient_solver(
        self: "CastSelf",
    ) -> "_117.LobattoIIICTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _117

        return self.__parent__._cast(_117.LobattoIIICTransientSolver)

    @property
    def newmark_transient_solver(self: "CastSelf") -> "_118.NewmarkTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _118

        return self.__parent__._cast(_118.NewmarkTransientSolver)

    @property
    def simple_velocity_based_step_halving_transient_solver(
        self: "CastSelf",
    ) -> "_121.SimpleVelocityBasedStepHalvingTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _121

        return self.__parent__._cast(_121.SimpleVelocityBasedStepHalvingTransientSolver)

    @property
    def step_halving_transient_solver(
        self: "CastSelf",
    ) -> "_126.StepHalvingTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _126

        return self.__parent__._cast(_126.StepHalvingTransientSolver)

    @property
    def wilson_theta_transient_solver(
        self: "CastSelf",
    ) -> "_130.WilsonThetaTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _130

        return self.__parent__._cast(_130.WilsonThetaTransientSolver)

    @property
    def transient_solver(self: "CastSelf") -> "TransientSolver":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class TransientSolver(_115.DynamicSolver):
    """TransientSolver

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TRANSIENT_SOLVER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def interface_analysis_time(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "InterfaceAnalysisTime")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def number_of_attempted_single_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfAttemptedSingleSteps")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_failed_time_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfFailedTimeSteps")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_failed_time_steps_at_minimum_time_step(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfFailedTimeStepsAtMinimumTimeStep"
        )

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_interface_time_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfInterfaceTimeSteps")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_successful_single_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfSuccessfulSingleSteps")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_time_steps_taken(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfTimeStepsTaken")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_times_single_step_function_failed(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfTimesSingleStepFunctionFailed"
        )

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_times_step_error_tolerance_not_met(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfTimesStepErrorToleranceNotMet"
        )

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def solver_status(self: "Self") -> "_96.TransientSolverStatus":
        """mastapy.nodal_analysis.TransientSolverStatus"""
        temp = pythonnet_property_get(self.wrapped, "SolverStatus")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.TransientSolverStatus"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._96", "TransientSolverStatus"
        )(value)

    @solver_status.setter
    @exception_bridge
    @enforce_parameter_types
    def solver_status(self: "Self", value: "_96.TransientSolverStatus") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.TransientSolverStatus"
        )
        pythonnet_property_set(self.wrapped, "SolverStatus", value)

    @exception_bridge
    def times_of_logged_results(self: "Self") -> "List[float]":
        """List[float]"""
        return conversion.to_list_any(
            pythonnet_method_call(self.wrapped, "TimesOfLoggedResults")
        )

    @property
    def cast_to(self: "Self") -> "_Cast_TransientSolver":
        """Cast to another type.

        Returns:
            _Cast_TransientSolver
        """
        return _Cast_TransientSolver(self)
